pymodaq_plugins_smaract (Smaract)
#################################


.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_smaract.svg
   :target: https://pypi.org/project/pymodaq_plugins_smaract/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/CEMES-CNRS/pymodaq_plugins_smaract/workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/CEMES-CNRS/pymodaq_plugins_smaract

PyMoDAQ plugin for actuators from Smaract (MCS_controller, ...)


Documentation: http://pymodaq.cnrs.fr/

Authors
=======

* David Bresteau (david.bresteau@cea.fr)
* Sebastien J. Weber (sebastien.weber@cnrs.fr)

.. if needed use this field

    Contributors
    ============

    * First Contributor
    * Other Contributors

Instruments
===========
Below is the list of instruments included in this plugin

Actuators
+++++++++

* **SmaractMCS** SLC linear stages with sensor (S option) with MCS controller
* **SmaractMCS2** SLC linear stages with sensor (S option) with MCS2 controller
* **Smaract** SLC linear or angular stages with or without sensors using the Instrumental-lib package


System requirements
===================

Operating system: Windows 7 or 10

Python: >=3.7

PyMoDAQ: >=3.1.2

